@@ -419,6 +419,8 @@ class geom2graph:
                 nodes_ads[node] = node_dict[node]['valency']
 
         if not edges_ads and not edges_pts:
+            print('Solving' + str(self.atoms[self.adsorbate_atoms].symbols))
+            print('No adsorbate/slab edges; trivial solution returned')
             return None, None
         
         model = pe.ConcreteModel()
@@ -492,7 +494,7 @@ class geom2graph:
         model.obj = pe.Objective(sense = pe.maximize, rule = edge_sum)
 
 
-        constraint_node_ads = set([i for sub in model.edges_ads for i in sub])
+        constraint_nodes = set([i for sub in model.edges_ads for i in sub])
         
         if edges_pts:
             constraint_nodes_pts = set([i for sub in model.edges_pts for i in sub])
@@ -534,6 +536,21 @@ class geom2graph:
                 self.graph.nodes[n[0]]['element']='M'
         
 if __name__=="__main__":
+    
+    import pickle as pk
+    import pandas as pd
+    pickleFile = open("Examples/ase_to_graph/LDA_ads_systems.pkl", 'rb')
+    LDA = pk.load(pickleFile)
+    df_LDA = pd.DataFrame(LDA).drop(['Graph'], axis=1)
+    
+    dfgeom = df_LDA.dropna()
+
+    geomlist = [geom2graph(surface_type = i['Substrate'], atoms = i['Geometry'], solver = 'glpk') for index, i in dfgeom.iterrows()]
+
+    for count,i in enumerate(geomlist):
+        print(count)
+        i.gen_graph(fill_bonds=True)
+    
     # vasp = geom2graph(vasp = 'Examples/ase_to_graph/CONTCARmethane')
     # vasp = geom2graph(vasp = 'Examples/ase_to_graph/CONTCARpraneetalphahdown')
     # vasp = geom2graph(vasp = 'Examples/ase_to_graph/CONTCAR_CHCH_holhol')
